import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

import aws_cdk.aws_ec2
import aws_cdk.aws_iam
import aws_cdk.aws_servicediscovery
import aws_cdk.core
import constructs

__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-appmesh", "1.41.0", __name__[0:-6], "aws-appmesh@1.41.0.jsii.tgz")

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
